==> openGion6.4.0.0_dev.zip: uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF45S.sql <==
/****************************************************************************/
/* GF45 ( 受注ﾃｰﾌﾞﾙｻﾝﾌﾟﾙ )                                                  */
/*                                                                          */
/* Created : 2015/11/16 16:20:03                                            */
/****************************************************************************/
CREATE TABLE GF45 (
   NOORDER  VARCHAR2 (  10 )                    NOT NULL            /*  10 受注番号 */
 , KNORDER  NUMBER   (   9 )                                        /*  20 受注金額 */
 , KNJISK   NUMBER   (   9 )                                        /*  30 実績金額 */
 , KNMIKM   NUMBER   (   9 )                                        /*  40 見込金額 */
 , SUORDER  NUMBER   (   9 )                                        /*  50 受注数   */
 , PN       VARCHAR2 (  11 )                                        /*  60 品番     */
 , PHOTO    VARCHAR2 ( 100 )                                        /*  70 写真     */
 , SINTYOKU NUMBER   ( 5,2 )                                        /*  80 進捗     */
 , NMCUST   VARCHAR2 ( 100 )                                        /*  90 納入先   */
 , DYORDER  VARCHAR2 (   8 )                                        /* 100 受注日   */
 , DYNOKI   VARCHAR2 (   8 )                                        /* 110 納期     */
 , UNIQ     NUMBER   (   9 )        DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ      VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET    VARCHAR2 (  14 )                                        /* 820 登録日時 */
 , PGSET    VARCHAR2 (  10 )                                        /* 830 作成PG   */
 , PGPSET   VARCHAR2 (  10 )                                        /* 840 作成親PG */
 , USRSET   VARCHAR2 (  10 )                                        /* 850 作成社員 */
 , DYUPD    VARCHAR2 (  14 )                                        /* 860 更新日時 */
 , PGUPD    VARCHAR2 (  10 )                                        /* 870 更新PG   */
 , PGPUPD   VARCHAR2 (  10 )                                        /* 880 更新親PG */
 , USRUPD   VARCHAR2 (  10 )                                        /* 890 更新者   */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K NEXT 16K );

CREATE SEQUENCE GF45S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF45T00 
  BEFORE INSERT ON GF45
  FOR EACH ROW 
  BEGIN 
    SELECT GF45S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion6.4.2.0_dev.zip: uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF45S.sql <==
/****************************************************************************/
/* GF45 ( 受注ﾃｰﾌﾞﾙｻﾝﾌﾟﾙ )                                                  */
/*                                                                          */
/* Created : 2016/01/07 17:07:19                                            */
/****************************************************************************/
CREATE TABLE GF45 (
   NOORDER  VARCHAR2 (  10 )                    NOT NULL            /*  10 受注番号 */
 , KNORDER  NUMBER   (   9 )                                        /*  20 受注金額 */
 , KNJISK   NUMBER   (   9 )                                        /*  30 実績金額 */
 , KNMIKM   NUMBER   (   9 )                                        /*  40 見込金額 */
 , SUORDER  NUMBER   (   9 )                                        /*  50 受注数   */
 , PN       VARCHAR2 (  11 )                                        /*  60 品番     */
 , PHOTO    VARCHAR2 ( 100 )                                        /*  70 写真     */
 , SINTYOKU NUMBER   ( 5,2 )                                        /*  80 進捗     */
 , NMCUST   VARCHAR2 ( 100 )                                        /*  90 納入先   */
 , DYORDER  VARCHAR2 (   8 )                                        /* 100 受注日   */
 , DYNOKI   VARCHAR2 (   8 )                                        /* 110 納期     */
 , UNIQ     NUMBER   (   9 )        DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ      VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET    VARCHAR2 (  14 )                                        /* 820 登録日時 */
 , PGSET    VARCHAR2 (  10 )                                        /* 830 作成PG   */
 , PGPSET   VARCHAR2 (  10 )                                        /* 840 作成親PG */
 , USRSET   VARCHAR2 (  10 )                                        /* 850 作成社員 */
 , DYUPD    VARCHAR2 (  14 )                                        /* 860 更新日時 */
 , PGUPD    VARCHAR2 (  10 )                                        /* 870 更新PG   */
 , PGPUPD   VARCHAR2 (  10 )                                        /* 880 更新親PG */
 , USRUPD   VARCHAR2 (  10 )                                        /* 890 更新者   */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );

CREATE SEQUENCE GF45S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF45T00 
  BEFORE INSERT ON GF45
  FOR EACH ROW 
  BEGIN 
    SELECT GF45S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
